==> tombi-0.6.9.tar.gz: tombi-0.6.9/python/tombi/README.md <==
<div align="center" style="display: flex; flex-direction: column; gap: 0;">
    <img src="https://raw.githubusercontent.com/tombi-toml/tombi/refs/heads/main/docs/public/tombi.svg" alt="Logo" style="display: block; margin: 0;">
    <img src="https://raw.githubusercontent.com/tombi-toml/tombi/refs/heads/main/docs/public/demo.gif" style="display: block; margin: 0;" />
</div>

<div align="center">

[![VS Code Marketplace](https://img.shields.io/visual-studio-marketplace/v/tombi-toml.tombi?label=VS%20Code%20Marketplace&logo=visual-studio-code&labelColor=374151&color=60a5fa)](https://marketplace.visualstudio.com/items?itemName=tombi-toml.tombi)
[![open vsx](https://img.shields.io/open-vsx/v/tombi-toml/tombi?label=Open%20VSX%20Registry&labelColor=374151&color=60a5fa)](https://open-vsx.org/extension/tombi-toml/tombi)
[![pypi](https://img.shields.io/pypi/v/tombi.svg?labelColor=374151&color=60a5fa)](https://pypi.python.org/pypi/tombi)
[![npm](https://img.shields.io/npm/v/tombi.svg?labelColor=374151&color=60a5fa)](https://www.npmjs.com/package/tombi)
[![toml-test](https://github.com/tombi-toml/tombi/actions/workflows/toml-test.yml/badge.svg)](https://github.com/tombi-toml/tombi/actions)
[![GitHub license](https://badgen.net/github/license/tombi-toml/tombi?style=flat-square&labelColor=374151)](https://github.com/tombi-toml/tombi/blob/main/LICENSE)

</div>

<br>

<div align="center">
    <div align="center" style="font-size: 2.0em; margin-bottom: 30px;">
        <strong> 🦅&nbsp; Feature-Rich TOML Toolkit &nbsp 🦅</strong>
    </div>
    Tombi(鳶) provides a Formatter, Linter, and Language Server
    <br><br>
    <a href="https://tombi-toml.github.io/tombi" style="font-size: 1.2em; color: #007acc; text-decoration: none;">
        📚 Documentation here 📚
    </a>
</div>

<br>

<div align="center">
    <h2 align="center" style="font-size: 2.0em; margin-bottom: 30px;">
        <strong>Support</strong>
    </h2>
    ❤️ If you like this project and would like to support us ❤️
    <br><br>
    <a href="https://www.buymeacoffee.com/tombi" target="_blank">
        <img
            src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png"
            alt="Buy Me A Coffee"
            style="width: 180px !important;"
        >
    </a>
</div>

==> tombi-0.6.15.tar.gz: tombi-0.6.15/python/tombi/README.md <==
<div align="center" style="display: flex; flex-direction: column; gap: 0;">
    <img src="https://raw.githubusercontent.com/tombi-toml/tombi/refs/heads/main/docs/public/tombi.svg" alt="Logo" style="display: block; margin: 0;">
    <img src="https://raw.githubusercontent.com/tombi-toml/tombi/refs/heads/main/docs/public/demo.gif" style="display: block; margin: 0;" />
</div>

<div align="center">

[![VS Code Marketplace](https://img.shields.io/visual-studio-marketplace/v/tombi-toml.tombi?label=VS%20Code%20Marketplace&logo=visual-studio-code&labelColor=374151&color=60a5fa)](https://marketplace.visualstudio.com/items?itemName=tombi-toml.tombi)
[![open vsx](https://img.shields.io/open-vsx/v/tombi-toml/tombi?label=Open%20VSX%20Registry&labelColor=374151&color=60a5fa)](https://open-vsx.org/extension/tombi-toml/tombi)
[![pypi](https://img.shields.io/pypi/v/tombi.svg?labelColor=374151&color=60a5fa)](https://pypi.python.org/pypi/tombi)
[![npm](https://img.shields.io/npm/v/tombi.svg?labelColor=374151&color=60a5fa)](https://www.npmjs.com/package/tombi)
[![toml-test](https://github.com/tombi-toml/tombi/actions/workflows/toml-test.yml/badge.svg)](https://github.com/tombi-toml/tombi/actions)
[![GitHub license](https://badgen.net/github/license/tombi-toml/tombi?style=flat-square&labelColor=374151)](https://github.com/tombi-toml/tombi/blob/main/LICENSE)

</div>

<br>

<div align="center">
    <div align="center" style="font-size: 2.0em; margin-bottom: 30px;">
        <strong> 🦅&nbsp; Feature-Rich TOML Toolkit &nbsp 🦅</strong>
    </div>
    Tombi(鳶 <code>/toɴbi/</code>) provides a Formatter, Linter, and Language Server
    <br><br>
    <a href="https://tombi-toml.github.io/tombi" style="font-size: 1.2em; color: #007acc; text-decoration: none;">
        📚 Documentation here 📚
    </a>
</div>

<br>

<div align="center">
<h2 align="center" style="font-size: 2.0em; margin-bottom: 30px;">
<strong>Quick Start</strong>
</h2>

To quickly try out Tombi's formatter, you can run:

<code style="display: block; white-space: pre-wrap;">    uvx tombi format    </code>
</div>

<div align="center">
    <h2 align="center" style="font-size: 2.0em; margin-bottom: 30px;">
        <strong>Support</strong>
    </h2>
    ❤️ If you like this project and would like to support us ❤️
    <br><br>
    <a href="https://www.buymeacoffee.com/tombi" target="_blank">
        <img
            src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png"
            alt="Buy Me A Coffee"
            style="width: 180px !important;"
        >
    </a>
</div>
